@@ -13,7 +13,6 @@
 
 from __future__ import with_statement
 
-import contextlib
 import os
 import re
 import shlex
@@ -22,18 +21,18 @@ from . import common
 from .. import errors
 from .. import image_io
 from .. import ipc
+from .. import iso639
 from .. import temporary
 from .. import utils
 
 _default_language = 'eng'
-_language_pattern = re.compile('^[a-z]{3}(-[a-z]+)?$')
+_language_pattern = re.compile('^[a-z]{3}(?:[+][a-z]{3})*$')
 _language_info_pattern = re.compile(r"^Supported languages: (.*)[.]$")
 
 class Engine(common.Engine):
 
     name = 'cuneiform'
     image_format = image_io.BMP
-    output_format = 'html'
     needs_utf8_fix = True
 
     executable = utils.property('cuneiform')
@@ -45,7 +44,7 @@ class Engine(common.Engine):
     def __init__(self, *args, **kwargs):
         assert args == ()
         common.Engine.__init__(self, *args, **kwargs)
-        self._iso_to_cuneiform = None # to be defined later
+        self._user_to_cuneiform = None # to be defined later
         self._cuneiform_to_iso = None # to be defined later
         try:
             self._languages = list(self._get_languages())
@@ -64,34 +63,35 @@ class Engine(common.Engine):
             )
         except OSError:
             raise errors.UnknownLanguageList
-        self._cuneiform_to_iso = dict(
-            ger='deu',
-            ruseng='rus-eng',  # mixed Russian-English
-            dut='nld',
-            cze='ces',
-            rum='ron',
-        )
+        self._cuneiform_to_iso = {}
+        self._user_to_cuneiform = {}
         try:
             for line in cuneiform.stdout:
                 m = _language_info_pattern.match(line)
                 if m is None:
                     continue
                 codes = m.group(1).split()
-                if 'slo' in codes:
-                    if 'slv' not in codes:
-                        # Cuneiform ≤ 1.0 mistakenly uses ‘slo’ as language code
-                        # for Slovenian.
-                        # https://bugs.launchpad.net/cuneiform-linux/+bug/707951
-                        self._cuneiform_to_iso['slo'] = 'slv'
+                for code in codes:
+                    if code == 'ruseng':
+                        isocode = 'rus+eng'
+                        # For compatibility with ocrodjvu ≤ 0.7.14:
+                        self._user_to_cuneiform[frozenset(['rus-eng'])] = code
+                    elif code == 'slo':
+                        if 'slv' not in codes:
+                            # Cuneiform ≤ 1.0 mistakenly uses ‘slo’ as language code
+                            # for Slovenian.
+                            # https://bugs.launchpad.net/cuneiform-linux/+bug/707951
+                            isocode = 'slv'
+                        else:
+                            # Both ‘slo’ and ‘slv’ are available. Let's guess that
+                            # the former means Slovak.
+                            isocode = 'slk'
                     else:
-                        # Both ‘slo’ and ‘slv’ are available. Let's guess that
-                        # the former means Slovak.
-                        self._cuneiform_to_iso['slo'] = 'slk'
-                self._iso_to_cuneiform = dict(
-                    (y, x) for x, y in
-                    self._cuneiform_to_iso.iteritems()
-                )
-                return map(self.cuneiform_to_iso, codes)
+                        isocode = iso639.b_to_t(code)
+                    self._cuneiform_to_iso[code] = isocode
+                    self._user_to_cuneiform[frozenset(isocode.split('+'))] = code
+                    yield isocode
+                return
         finally:
             try:
                 cuneiform.wait()
@@ -105,26 +105,38 @@ class Engine(common.Engine):
     def get_default_language(cls):
         return _default_language
 
-    def has_language(self, language):
+    def check_language(self, language):
         if language == 'slo':
             # Normally we accept Cuneiform-specific language code. This is an
             # exception: ‘slo’ is Slovenian in Cuneiform ≤ 1.0 but it is Slovak
-            # according in ISO 639-2.
+            # according to ISO 639-2.
             language = 'slk'
         else:
             language = self.cuneiform_to_iso(language)
-        return language in self._languages
+        language = self.normalize_iso(language)
+        if not _language_pattern.match(language):
+            raise errors.InvalidLanguageId(language)
+        if language not in self._languages:
+            raise errors.MissingLanguagePack(language)
 
     def list_languages(self):
         return iter(self._languages)
 
-    def iso_to_cuneiform(self, language):
-        return self._iso_to_cuneiform.get(language, language)
+    def user_to_cuneiform(self, language):
+        language_set = frozenset(
+            iso639.b_to_t(code, permissive=True)
+            for code in language.split('+')
+        )
+        return self._user_to_cuneiform.get(language_set, language)
 
     def cuneiform_to_iso(self, language):
         return self._cuneiform_to_iso.get(language, language)
 
-    @contextlib.contextmanager
+    def normalize_iso(self, language):
+        language = self.user_to_cuneiform(language)
+        language = self.cuneiform_to_iso(language)
+        return language
+
     def recognize(self, image, language, *args, **kwargs):
         with temporary.directory() as hocr_directory:
             # A separate non-world-writable directory is needed, as Cuneiform
@@ -133,7 +145,7 @@ class Engine(common.Engine):
             worker = ipc.Subprocess(
                 [
                     self.executable,
-                    '-l', self.iso_to_cuneiform(language),
+                    '-l', self.user_to_cuneiform(language),
                     '-f', 'hocr',
                     '-o', hocr_file_name
                 ] + self.extra_args + [image.name],
@@ -143,7 +155,10 @@ class Engine(common.Engine):
             worker.stdin.close()
             worker.wait()
             with open(hocr_file_name, 'r') as hocr_file:
-                yield hocr_file
+                return common.Output(
+                    hocr_file.read(),
+                    format='html',
+                )
 
     def extract_text(self, *args, **kwargs):
         return self._hocr.extract_text(*args, **kwargs)
