@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008, 2009, 2010, 2011 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008, 2009, 2010, 2011, 2013 Jakub Wilk <jwilk@jwilk.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,7 +11,6 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
-import contextlib
 import shlex
 
 from . import common
@@ -25,7 +24,6 @@ class Engine(common.Engine):
 
     name = 'ocropus'
     image_format = image_io.PNM
-    output_format = 'html'
 
     executable = utils.property('ocroscript')
     tesseract_executable = utils.property('tesseract')
@@ -76,13 +74,12 @@ class Engine(common.Engine):
     def get_default_language(cls):
         return tesseract.Engine.get_default_language()
 
-    def has_language(self, language):
-        return self.tesseract.has_language(language)
+    def check_language(self, language):
+        return self.tesseract.check_language(language)
 
     def list_languages(self):
         return self.tesseract.list_languages()
 
-    @contextlib.contextmanager
     def recognize(self, image, language, details=None, uax29=None):
         hocr = self._hocr
         if details is None:
@@ -101,7 +98,10 @@ class Engine(common.Engine):
             env=dict(tesslanguage=language),
         )
         try:
-            yield ocropus.stdout
+            return common.Output(
+                ocropus.stdout.read(),
+                format='html',
+            )
         finally:
             ocropus.wait()
 
