@@ -15,7 +15,7 @@
 Process hOCR documents.
 
 The hOCR format specification:
-http://docs.google.com/Doc?id=dfxcv4vc_67g844kf
+https://docs.google.com/Doc?id=dfxcv4vc_67g844kf
 '''
 
 import functools
@@ -26,7 +26,7 @@ from . import utils
 try:
     from lxml import etree
 except ImportError, ex:
-    utils.enhance_import_error(ex, 'lxml', 'python-lxml', 'http://codespeak.net/lxml/')
+    utils.enhance_import_error(ex, 'lxml', 'python-lxml', 'http://lxml.de/')
     raise
 
 from . import errors
@@ -424,11 +424,11 @@ def read_document(stream, settings):
         # Ideally, this should never be needed, but some OCR engines produce
         # such broken HTML:
         #  * https://bugs.launchpad.net/cuneiform-linux/+bug/585418
-        #  * http://code.google.com/p/tesseract-ocr/issues/detail?id=690
+        #  * https://code.google.com/p/tesseract-ocr/issues/detail?id=690
         #
         # Moreover, the HTML parsers trip over such errors:
         #  * https://bugs.launchpad.net/lxml/+bug/690110
-        #  * http://bugs.debian.org/671842
+        #  * https://bugs.debian.org/671842
         #
         # FIXME: This work-around is ugly and should be dropped at some point.
         contents = stream.read()
